Utils class

class with useful methods

Constructors

Utils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

imgAssets2Uint8List(String path) → Future<Uint8List>
verBorderType(int borderType) → int
verKernelSize(List<double> kernelSize) → List<double>
verKernelSizeInt(List<int> kernelSize) → List<int>